@@ -17,9 +17,9 @@
  * along with QCAD.
  */
 
-include("scripts/DefaultAction.js");
 include("scripts/Edit/DrawingPreferences/PageSettings/PageSettings.js");
 include("scripts/File/File.js");
+include("scripts/File/NewFile/NewFile.js");
 include("scripts/File/Print/Print.js");
 include("scripts/sprintf.js");
 
@@ -29,19 +29,106 @@ include("scripts/sprintf.js");
  * the drawing.
  */
 function PrintPreview(guiAction) {
-    DefaultAction.call(this, guiAction);
+    EAction.call(this, guiAction);
+}
+
+PrintPreview.prototype = new EAction();
+PrintPreview.includeBasePath = includeBasePath;
+PrintPreview.instance = undefined;
+
+PrintPreview.getInstance = function() {
+    return PrintPreview.instance;
+};
+
+PrintPreview.isRunning = function() {
+    var di = EAction.getDocumentInterface();
+    if (isNull(di)) {
+        return false;
+    }
+
+    var a = di.getDefaultAction();
+    var ga = a.getGuiAction();
+    if (isNull(ga)) {
+        return true;
+    }
+    else {
+        return false;
+    }
+};
+
+/**
+ * Starts the print preview.
+ */
+PrintPreview.start = function(initialAction) {
+    var di = EAction.getDocumentInterface();
+    var a = di.getDefaultAction();
+    a.finishEvent();
+    PrintPreview.instance = new PrintPreviewImpl();
+    if (!isNull(initialAction)) {
+        PrintPreview.instance.initialAction = initialAction;
+    }
+    di.setDefaultAction(PrintPreview.instance);
+
+    var ga = RGuiAction.getByScriptFile("scripts/File/PrintPreview/PrintPreview.js")
+    if (!isNull(ga)) {
+        ga.setChecked(true);
+    }
+};
+
+/**
+ * Exits the print preview.
+ */
+PrintPreview.exit = function() {
+    var di = EAction.getDocumentInterface();
+    var a = di.getDefaultAction();
+    a.finishEvent();
+    NewFile.setupDefaultAction(di);
+
+    var ga = RGuiAction.getByScriptFile("scripts/File/PrintPreview/PrintPreview.js")
+    if (!isNull(ga)) {
+        ga.setChecked(false);
+    }
+};
+
+PrintPreview.prototype.beginEvent = function() {
+    if (PrintPreview.isRunning()) {
+        // exit print preview:
+        PrintPreview.exit();
+    }
+    else {
+        // start print preview:
+        PrintPreview.start();
+    }
+
+    this.terminate();
+    return;
+};
+
+
+
+/**
+ * Implementation of interactive print preview action.
+ * Intended to be used as default action.
+ */
+function PrintPreviewImpl(guiAction) {
+    // parent class can be DefaultAction or other configured
+    // default action:
+    var defaultActionClass = NewFile.getDefaultActionClass();
+    this.parentClass = global[defaultActionClass];
+
+    this.parentClass.call(this, guiAction);
 
     this.enableSlotPaperSizeChanged = false;
-    
-    this.setUiOptions(PrintPreview.includeBasePath + "/PrintPreview.ui");
-    
+
+    this.setUiOptions(PrintPreviewImpl.includeBasePath + "/PrintPreview.ui");
+
     this.panningOffset = false;
     this.panOffsetOrigin = new RVector();
 
     this.updateDisabled = false;
 
-    var bitmap = new QBitmap(PrintPreview.includeBasePath + "/PrintPreviewOffsetCursor.png", "PNG");
-    var mask = new QBitmap(PrintPreview.includeBasePath + "/PrintPreviewOffsetCursorMask.png", "PNG");
+    var bitmap = new QBitmap(PrintPreviewImpl.includeBasePath + "/PrintPreviewOffsetCursor.png", "PNG");
+    var mask = new QBitmap(PrintPreviewImpl.includeBasePath + "/PrintPreviewOffsetCursorMask.png", "PNG");
     this.cursor = new QCursor(bitmap, mask, 15, 13);
     this.view = undefined;
     this.saveView = false;
@@ -49,70 +136,38 @@ function PrintPreview(guiAction) {
     this.savedOffset = undefined;
 }
 
-PrintPreview.prototype = new DefaultAction();
-PrintPreview.includeBasePath = includeBasePath;
+PrintPreviewImpl.prototype = NewFile.getDefaultAction();
+PrintPreviewImpl.includeBasePath = includeBasePath;
 
-if (typeof(printPreviewRunning)==="undefined") {
-    printPreviewRunning = false;
-}
-
-/**
- * Additional states of PrintPreview compared with base class DefaultAction.
- */
-PrintPreview.State = {
+PrintPreviewImpl.State = {
     SettingOffset : 100
 };
 
-PrintPreview.isRunning = function() {
-    return printPreviewRunning;
-};
-
-PrintPreview.getInstance = function() {
-    return printPreviewInstance;
-};
-
-PrintPreview.prototype.beginEvent = function() {
-    if (PrintPreview.isRunning()) {
-        // allows use of print preview button to close print preview:
-        if (!isNull(printPreviewInstance)) {
-            printPreviewInstance.terminate();
-        }
-        if (!isNull(this.guiAction)) {
-            this.guiAction.setChecked(false);
-        }
-        this.terminate();
-        return;
-    }
+PrintPreviewImpl.prototype.beginEvent = function() {
+    var di = this.getDocumentInterface();
 
     if (this.saveView===true) {
         this.savedScale = Print.getScale(this.getDocument());
         this.savedOffset = Print.getOffset(this.getDocument());
     }
 
-    if (!isNull(this.guiAction)) {
-        this.guiAction.setChecked(true);
-    }
+//    if (!isNull(this.guiAction)) {
+//        this.guiAction.setChecked(true);
+//    }
 
     // globals:
-    printPreviewRunning = true;
-    printPreviewInstance = this;
+    //PrintPreview.setRunning(true);
+    //PrintPreview.setInstance(this);
 
     var mdiChild = EAction.getMdiChild();
     this.view = mdiChild.getLastKnownViewWithFocus();
 
-    DefaultAction.prototype.beginEvent.call(this);
+    this.parentClass.prototype.beginEvent.call(this);
 
     if (!isNull(this.view)) {
         var document = this.getDocument();
         this.bgColor = this.view.getBackgroundColor();
 
-        // background needs to be set to white (or other user preference)
-        // for printing / preview:
-        this.view.setBackgroundColor(Print.getBackgroundColor(document));
-        this.view.setColorMode(Print.getColorMode(document));
-        this.view.setHairlineMode(Print.getHairlineMode(document));
-        this.view.setPrintPreview(true);
-
         this.updateBackgroundDecoration();
 
         if (!isNull(this.view.getScene())) {
@@ -125,7 +180,6 @@ PrintPreview.prototype.beginEvent = function() {
         }
 
         // needed to update pattern scaling according to drawing scale:
-        var di = EAction.getDocumentInterface();
         di.regenerateScenes();
     }
 
@@ -152,15 +206,22 @@ PrintPreview.prototype.beginEvent = function() {
     this.pAdapter = new RPreferencesListenerAdapter();
     appWin.addPreferencesListener(this.pAdapter);
     this.pAdapter.preferencesUpdated.connect(this, "updateFromPreferences");
+
+    this.bAdapter = new RBlockListenerAdapter();
+    appWin.addBlockListener(this.bAdapter);
+    this.bAdapter.blocksUpdated.connect(this, "updateBackgroundTransform");
+    this.bAdapter.currentBlockSet.connect(this, "updateBackgroundTransform");
+    this.bAdapter.blocksUpdated.connect(this, "updateBackgroundDecoration");
+    this.bAdapter.currentBlockSet.connect(this, "updateBackgroundDecoration");
 };
 
 /**
  * Handles additional state changes for offset moving state.
  */
-PrintPreview.prototype.setState = function(state) {
-    DefaultAction.prototype.setState.call(this, state);
+PrintPreviewImpl.prototype.setState = function(state) {
+    this.parentClass.prototype.setState.call(this, state);
 
-    if (this.state === PrintPreview.State.SettingOffset) {
+    if (this.state === PrintPreviewImpl.State.SettingOffset) {
         EAction.getDocumentInterface().setClickMode(RAction.PickingDisabled);
         this.setCursor(this.cursor, "PrintPreviewOffsetCursor");
         EAction.showMainTools();
@@ -171,17 +232,19 @@ PrintPreview.prototype.setState = function(state) {
     var optionsToolBar = EAction.getOptionsToolBar();
     var offsetButton = optionsToolBar.findChild("Offset");
     if (offsetButton) {
-        offsetButton.checked = (this.state == PrintPreview.State.SettingOffset);
+        offsetButton.checked = (this.state == PrintPreviewImpl.State.SettingOffset);
     }
 };
 
-PrintPreview.prototype.suspendEvent = function() {
+PrintPreviewImpl.prototype.suspendEvent = function() {
     EAction.prototype.suspendEvent.call(this);
 };
 
-PrintPreview.prototype.finishEvent = function() {
-    DefaultAction.prototype.finishEvent.call(this);
-        
+PrintPreviewImpl.prototype.finishEvent = function() {
+    qDebug("PrintPreviewImpl.prototype.finishEvent");
+    this.parentClass.prototype.finishEvent.call(this);
+    var di = this.getDocumentInterface();
+
     if (!isNull(this.view)) {
         this.view.setPrintPreview(false);
         this.view.setBackgroundColor(this.bgColor);
@@ -197,22 +260,23 @@ PrintPreview.prototype.finishEvent = function() {
         }
 
         // needed to update pattern scaling without using drawing scale:
-        var di = EAction.getDocumentInterface();
-        di.regenerateScenes();
+        if (!isNull(di)) {
+            di.regenerateScenes();
+        }
 
         var action = RGuiAction.getByScriptFile("scripts/Edit/DrawingPreferences/DrawingPreferences.js");
         action.triggered.disconnect(this, "updateBackgroundDecoration");
     }
 
-    printPreviewRunning = false;
-    printPreviewInstance = undefined;
+    //PrintPreviewImpl.setRunning(false);
+    //PrintPreviewImpl.setInstance(undefined);
 
     if (this.saveView===true) {
         if (!isNull(this.savedScale)) {
-            Print.setScale(this.getDocument(), this.savedScale);
+            Print.setScale(di.getDocument(), this.savedScale);
         }
         if (!isNull(this.savedOffset)) {
-            Print.setOffset(this.getDocument(), this.savedOffset);
+            Print.setOffset(di.getDocument(), this.savedOffset);
         }
     }
 
@@ -220,13 +284,16 @@ PrintPreview.prototype.finishEvent = function() {
     if (!isNull(this.pAdapter)) {
         appWin.removePreferencesListener(this.pAdapter);
     }
+    if (!isNull(this.bAdapter)) {
+        appWin.removeBlockListener(this.bAdapter);
+    }
 };
 
 /**
  * Implements moving of paper (offset).
  */
-PrintPreview.prototype.mousePressEvent = function(event) {
-    if (this.state === PrintPreview.State.SettingOffset) {
+PrintPreviewImpl.prototype.mousePressEvent = function(event) {
+    if (this.state === PrintPreviewImpl.State.SettingOffset) {
         if (event.button() == Qt.LeftButton &&
             event.modifiers().valueOf() != Qt.ControlModifier.valueOf()) {
 
@@ -235,7 +302,7 @@ PrintPreview.prototype.mousePressEvent = function(event) {
         }
     }
     else {
-        DefaultAction.prototype.mousePressEvent.call(this, event);
+        this.parentClass.prototype.mousePressEvent.call(this, event);
     }
 };
 
@@ -243,7 +310,7 @@ PrintPreview.prototype.mousePressEvent = function(event) {
  * Reimplemented from EAction to prevent that a right-click closes the
  * print preview.
  */
-//PrintPreview.prototype.mouseReleaseEvent = function(event) {
+//PrintPreviewImpl.prototype.mouseReleaseEvent = function(event) {
 //    if (event.button() == Qt.RightButton) {
 //        if (this.state!=DefaultAction.State.Neutral) {
 //            EAction.getDocumentInterface().clearPreview();
@@ -252,16 +319,16 @@ PrintPreview.prototype.mousePressEvent = function(event) {
 //        }
 //    }
 //    else {
-//        DefaultAction.prototype.mouseReleaseEvent.call(this, event);
+//        this.parentClass.prototype.mouseReleaseEvent.call(this, event);
 //    }
 //};
 
 /**
  * Implements moving of paper (offset).
  */
-PrintPreview.prototype.mouseMoveEvent = function(event) {
-    if (this.state !== PrintPreview.State.SettingOffset) {
-        DefaultAction.prototype.mouseMoveEvent.call(this, event);
+PrintPreviewImpl.prototype.mouseMoveEvent = function(event) {
+    if (this.state !== PrintPreviewImpl.State.SettingOffset) {
+        this.parentClass.prototype.mouseMoveEvent.call(this, event);
         return;
     }
 
@@ -297,7 +364,7 @@ PrintPreview.prototype.mouseMoveEvent = function(event) {
  * Reimplementation from EAction. Implements initialization of options
  * toolbar from member variables.
  */
-PrintPreview.prototype.showUiOptions = function(resume) {
+PrintPreviewImpl.prototype.showUiOptions = function(resume) {
     this.updateDisabled = true;
     EAction.prototype.showUiOptions.call(this, resume);
     this.updateDisabled = false;
@@ -354,7 +421,7 @@ PrintPreview.prototype.showUiOptions = function(resume) {
 
     widgets["Portrait"].blockSignals(true);
     widgets["Landscape"].blockSignals(true);
-    if (Print.getPageOrientationEnum() == QPrinter.Portrait) {
+    if (Print.getPageOrientationEnum(document).valueOf() === QPrinter.Portrait.valueOf()) {
         widgets["Portrait"].checked=true;
     } else {
         widgets["Landscape"].checked=true;
@@ -366,11 +433,11 @@ PrintPreview.prototype.showUiOptions = function(resume) {
 /**
  * Initializes the scale combo box in the options toolbar with defaults.
  */
-PrintPreview.prototype.initUiOptions = function(resume, optionsToolBar) {
+PrintPreviewImpl.prototype.initUiOptions = function(resume, optionsToolBar) {
     this.initScaleCombo();
 };
 
-PrintPreview.prototype.initScaleCombo = function() {
+PrintPreviewImpl.prototype.initScaleCombo = function() {
     var optionsToolBar = EAction.getOptionsToolBar();
     var scaleCombo = optionsToolBar.findChild("Scale");
     scaleCombo.blockSignals(true);
@@ -384,7 +451,7 @@ PrintPreview.prototype.initScaleCombo = function() {
     scaleCombo.blockSignals(false);
 };
 
-PrintPreview.prototype.hideUiOptions = function() {
+PrintPreviewImpl.prototype.hideUiOptions = function() {
     EAction.prototype.hideUiOptions.call(this, false);
 };
 
@@ -392,16 +459,27 @@ PrintPreview.prototype.hideUiOptions = function() {
  * Called to update the background decoration (paper borders) if the scale
  * or paper settings change.
  */
-PrintPreview.prototype.updateBackgroundDecoration = function() {
+PrintPreviewImpl.prototype.updateBackgroundDecoration = function() {
+    var document = this.getDocument();
+
+    if (isNull(document) || isNull(this.view)) {
+        return;
+    }
+
+    // initialize graphics view for printing / print preview:
+    this.view.setBackgroundColor(Print.getBackgroundColor(document));
+    this.view.setColorMode(Print.getColorMode(document));
+    this.view.setHairlineMode(Print.getHairlineMode(document));
+    this.view.setPrintPreview(true);
+
     this.view.clearBackground();
 
-    var document = this.getDocument();
     var pages = Print.getPages(document);
     var backgroundColor = Print.getBackgroundColor(document);
     var i, color, path;
 
     if (pages.length===0) {
-        qWarning("PrintPreview.prototype.updateBackgroundDecoration: no pages");
+        qWarning("PrintPreviewImpl.prototype.updateBackgroundDecoration: no pages");
         return;
     }
 
@@ -455,7 +533,7 @@ PrintPreview.prototype.updateBackgroundDecoration = function() {
     }
 
     if (pages.length===0) {
-        qWarning("PrintPreview.js: no pages");
+        qWarning("PrintPreviewImpl.js: no pages");
     }
 
     for (i = 0; i < pages.length; ++i) {
@@ -481,13 +559,18 @@ PrintPreview.prototype.updateBackgroundDecoration = function() {
 /**
  * Overwritable hook to add more decorations to the print preview.
  */
-PrintPreview.prototype.addDecorations = function(pages) {};
+PrintPreviewImpl.prototype.addDecorations = function(pages) {};
 
 /**
  * Updates the background decoration transformation.
  */
-PrintPreview.prototype.updateBackgroundTransform = function() {
+PrintPreviewImpl.prototype.updateBackgroundTransform = function() {
     var document = EAction.getDocument();
+
+    if (isNull(document)) {
+        return;
+    }
+
     var scale = Print.getScale(document);
     var offset = Print.getOffset(document);
 
@@ -496,13 +579,15 @@ PrintPreview.prototype.updateBackgroundTransform = function() {
     var unitScale = RUnit.convert(1.0, RS.Millimeter, document.getUnit());
     var factor = 1.0 / scale * unitScale;
 
-    this.view.setBackgroundTransform(factor, offset);
+    if (!isNull(this.view)) {
+        this.view.setBackgroundTransform(factor, offset);
+    }
 };
 
 /**
  * Draws the paper border for the given page.
  */
-PrintPreview.prototype.drawPaper = function(path, border) {
+PrintPreviewImpl.prototype.drawPaper = function(path, border) {
     var document = EAction.getDocument();
     var paperBorder = Print.getPaperBorder(document, border);
     if (!paperBorder.isValid()) {
@@ -514,7 +599,7 @@ PrintPreview.prototype.drawPaper = function(path, border) {
 /**
  * Draws the glue margins for the given page.
  */
-PrintPreview.prototype.drawGlueMargins = function(path, border) {
+PrintPreviewImpl.prototype.drawGlueMargins = function(path, border) {
     if (!border.isValid()) {
         return;
     }
@@ -524,7 +609,7 @@ PrintPreview.prototype.drawGlueMargins = function(path, border) {
 /**
  * Draws the shadow for the given page.
  */
-PrintPreview.prototype.drawShadow = function(path, border) {
+PrintPreviewImpl.prototype.drawShadow = function(path, border) {
     var document = EAction.getDocument();
     var paper = Print.getPaperBorder(document, border);
     var offset = Print.getPaperSizeMM(document).width() * 0.02;
@@ -535,14 +620,7 @@ PrintPreview.prototype.drawShadow = function(path, border) {
     path.addRect(shadow);
 };
 
-PrintPreview.prototype.slotPdfExport = function() {
-    PrintPreview.slotPdfExport();
-};
-
-/**
- * Called when user clicks the PDF export button in the options toolbar.
- */
-PrintPreview.slotPdfExport = function() {
+PrintPreviewImpl.prototype.slotPdfExport = function() {
     var appWin = EAction.getMainWindow();
     var fileName = EAction.getDocument().getFileName();
     var initialFileName = QDir.homePath();
@@ -564,7 +642,7 @@ PrintPreview.slotPdfExport = function() {
 
     appWin.handleUserMessage(qsTr("Exporting to %1...").arg(pdfFile));
 
-    var success = PrintPreview.slotPrint(pdfFile);
+    var success = this.slotPrint(pdfFile);
 
     if (success) {
         appWin.handleUserMessage(qsTr("Export complete: %1").arg(pdfFile));
@@ -574,14 +652,22 @@ PrintPreview.slotPdfExport = function() {
     }
 };
 
-PrintPreview.prototype.slotPrint = function(pdfFile) {
-    return PrintPreview.slotPrint(pdfFile);
+/**
+ * Called when user clicks the PDF export button in the options toolbar.
+ */
+PrintPreviewImpl.slotPdfExport = function() {
+    var pp = PrintPreviewImpl.getInstance();
+    pp.slotPdfExport();
+};
+
+PrintPreviewImpl.prototype.slotPrint = function(pdfFile) {
+    return PrintPreviewImpl.slotPrint(pdfFile);
 };
 
 /**
  * Prints the drawing or exports it to the given PDF file.
  */
-PrintPreview.slotPrint = function(pdfFile) {
+PrintPreviewImpl.slotPrint = function(pdfFile) {
     var mdiChild = EAction.getMdiChild();
     var view = mdiChild.getLastKnownViewWithFocus();
     var print = new Print(undefined, EAction.getDocument(), view);
@@ -591,7 +677,7 @@ PrintPreview.slotPrint = function(pdfFile) {
 /**
  * Called whenever the user changes the drawing scale in the print preview.
  */
-PrintPreview.prototype.slotScaleChanged = function(scaleString) {
+PrintPreviewImpl.prototype.slotScaleChanged = function(scaleString) {
     if (this.updateDisabled===true) {
         return;
     }
@@ -611,22 +697,22 @@ PrintPreview.prototype.slotScaleChanged = function(scaleString) {
     di.regenerateScenes();
 };
 
-PrintPreview.setScale = function(document, scale) {
-    PrintPreview.setScaleString(document, sprintf("%.6f", scale));
+PrintPreviewImpl.setScale = function(document, scale) {
+    PrintPreviewImpl.setScaleString(document, sprintf("%.6f", scale));
 };
 
-PrintPreview.setScaleString = function(document, scaleString) {
+PrintPreviewImpl.setScaleString = function(document, scaleString) {
     Print.setScaleString(document, scaleString);
 
-    PrintPreview.updateScaleString(document);
+    PrintPreviewImpl.updateScaleString(document);
 };
 
-PrintPreview.updateScaleString = function(document) {
+PrintPreviewImpl.updateScaleString = function(document) {
     var optionsToolBar = EAction.getOptionsToolBar();
     var scaleCombo = optionsToolBar.findChild("Scale");
     if (Print.getScale(document) != RMath.parseScale(scaleCombo.currentText)) {
         scaleCombo.blockSignals(true);
-        scaleCombo.setEditText(Print.getScaleString());
+        scaleCombo.setEditText(Print.getScaleString(document));
         scaleCombo.blockSignals(false);
     }
 };
@@ -635,13 +721,13 @@ PrintPreview.updateScaleString = function(document) {
  * Triggered by the offset tool button in the options toolbar.
  * Activates / deactivates the offset tool.
  */
-PrintPreview.prototype.slotOffsetChanged = function(checked) {
+PrintPreviewImpl.prototype.slotOffsetChanged = function(checked) {
     if (this.updateDisabled===true) {
         return;
     }
 
     if (checked) {
-        this.setState(PrintPreview.State.SettingOffset);
+        this.setState(PrintPreviewImpl.State.SettingOffset);
     }
     else {
         this.setState(DefaultAction.State.Neutral);
@@ -652,15 +738,15 @@ PrintPreview.prototype.slotOffsetChanged = function(checked) {
  * Triggered by the "Done" button in the options toolbar.
  * Terminates this action and returns to normal drawing mode.
  */
-PrintPreview.prototype.slotDone = function() {
-    this.terminate();
+PrintPreviewImpl.prototype.slotDone = function() {
+    PrintPreview.exit();
 };
 
 /**
  * Triggered by the b/w button in the options toolbar.
  * Activates / deactivates the black white mode.
  */
-PrintPreview.prototype.slotFullColorChanged = function(checked) {
+PrintPreviewImpl.prototype.slotFullColorChanged = function(checked) {
     if (this.updateDisabled===true) {
         return;
     }
@@ -670,7 +756,7 @@ PrintPreview.prototype.slotFullColorChanged = function(checked) {
     }
 };
 
-PrintPreview.prototype.slotBlackWhiteChanged = function(checked) {
+PrintPreviewImpl.prototype.slotBlackWhiteChanged = function(checked) {
     if (this.updateDisabled===true) {
         return;
     }
@@ -680,7 +766,7 @@ PrintPreview.prototype.slotBlackWhiteChanged = function(checked) {
     }
 };
 
-PrintPreview.prototype.slotGrayscaleChanged = function(checked) {
+PrintPreviewImpl.prototype.slotGrayscaleChanged = function(checked) {
     if (this.updateDisabled===true) {
         return;
     }
@@ -690,20 +776,19 @@ PrintPreview.prototype.slotGrayscaleChanged = function(checked) {
     }
 };
 
-PrintPreview.prototype.colorModeUpdate = function() {
+PrintPreviewImpl.prototype.colorModeUpdate = function() {
     if (!isNull(this.view)) {
-        this.view.setColorMode(Print.getColorMode());
+        this.view.setColorMode(Print.getColorMode(EAction.getDocument()));
         this.view.regenerate(true);
     }    
 };
 
-PrintPreview.prototype.slotHairlineChanged = function(checked) {
+PrintPreviewImpl.prototype.slotHairlineChanged = function(checked) {
     if (this.updateDisabled===true) {
         return;
     }
     Print.setHairlineMode(EAction.getDocument(), checked);
     if (!isNull(this.view)) {
-        qDebug("hairline mode: ", checked);
         this.view.setHairlineMode(checked)
         this.view.regenerate(true);
     }
@@ -713,7 +798,7 @@ PrintPreview.prototype.slotHairlineChanged = function(checked) {
 /**
  * Page borders toggled in options toolbar.
  */
-PrintPreview.prototype.slotShowPaperBordersChanged = function(checked) {
+PrintPreviewImpl.prototype.slotShowPaperBordersChanged = function(checked) {
     if (this.updateDisabled===true) {
         return;
     }
@@ -726,7 +811,7 @@ PrintPreview.prototype.slotShowPaperBordersChanged = function(checked) {
 /**
  * Crop marks toggled in options toolbar.
  */
-PrintPreview.prototype.slotPrintCropMarksChanged = function(checked) {
+PrintPreviewImpl.prototype.slotPrintCropMarksChanged = function(checked) {
     if (this.updateDisabled===true) {
         return;
     }
@@ -739,10 +824,10 @@ PrintPreview.prototype.slotPrintCropMarksChanged = function(checked) {
 /**
  * Auto fit box to page.
  */
-PrintPreview.prototype.slotAutoFitBox = function(box) {
+PrintPreviewImpl.prototype.slotAutoFitBox = function(box) {
     var document = this.getDocument();
     Print.autoFitBox(document, box);
-    PrintPreview.updateScaleString(document);
+    PrintPreviewImpl.updateScaleString(document);
 
     // needed to update pattern scaling according to drawing scale:
     var di = this.getDocumentInterface();
@@ -751,15 +836,16 @@ PrintPreview.prototype.slotAutoFitBox = function(box) {
     this.updateBackgroundTransform();
     //this.slotAutoZoomToPage();
     this.updateBackgroundDecoration();
+    this.showUiOptions(true);
 };
 
 /**
  * Auto fit drawing button clicked in options toolbar.
  */
-PrintPreview.prototype.slotAutoFitDrawing = function() {
+PrintPreviewImpl.prototype.slotAutoFitDrawing = function() {
     var document = this.getDocument();
     Print.autoFitDrawing(document);
-    PrintPreview.updateScaleString(document);
+    PrintPreviewImpl.updateScaleString(document);
 
     // needed to update pattern scaling according to drawing scale:
     var di = this.getDocumentInterface();
@@ -768,9 +854,10 @@ PrintPreview.prototype.slotAutoFitDrawing = function() {
     this.updateBackgroundTransform();
     this.slotAutoZoomToPage();
     this.updateBackgroundDecoration();
+    this.showUiOptions(true);
 };
 
-PrintPreview.prototype.slotAutoCenter = function() {
+PrintPreviewImpl.prototype.slotAutoCenter = function() {
     Print.autoCenter(this.getDocument());
 
     this.updateBackgroundTransform();
@@ -778,7 +865,7 @@ PrintPreview.prototype.slotAutoCenter = function() {
     this.updateBackgroundDecoration();
 };
 
-PrintPreview.prototype.slotPortraitChanged = function() {
+PrintPreviewImpl.prototype.slotPortraitChanged = function() {
     if (this.updateDisabled===true) {
         return;
     }
@@ -789,7 +876,7 @@ PrintPreview.prototype.slotPortraitChanged = function() {
     this.slotAutoZoomToPage();
 };
 
-PrintPreview.prototype.slotLandscapeChanged = function() {
+PrintPreviewImpl.prototype.slotLandscapeChanged = function() {
     if (this.updateDisabled===true) {
         return;
     }
@@ -803,11 +890,11 @@ PrintPreview.prototype.slotLandscapeChanged = function() {
 /**
  * \return Maximum extents of paper
  */
-PrintPreview.prototype.getPaperBox = function() {
+PrintPreviewImpl.prototype.getPaperBox = function() {
     return Print.getPaperBox(this.getDocument());
 };
 
-PrintPreview.prototype.slotAutoZoomToPage = function() {
+PrintPreviewImpl.prototype.slotAutoZoomToPage = function() {
     if (!isNull(this.view)) {
         var pBox = this.getPaperBox();
         this.view.zoomTo(pBox, 10);
@@ -818,6 +905,8 @@ PrintPreview.prototype.slotAutoZoomToPage = function() {
  * Updates the background (paper preview) transform when page settings
  * are changed (e.g. offset).
  */
-PrintPreview.prototype.updateFromPreferences = function() {
+PrintPreviewImpl.prototype.updateFromPreferences = function() {
+    this.showUiOptions(true);
+    this.updateBackgroundDecoration();
     this.updateBackgroundTransform();
 };
